@@ -21,7 +21,7 @@
 #'
 #' \bold{\code{show_labels} options (multi-select)}
 #' \itemize{
-#' \item schema.epid - \bold{TRUE}, \bold{FALSE}, "sn", "epid", "date", "case_nm", "length_label", "length_arrow", "case_overlap_methods" or "recurrence_overlap_methods"
+#' \item schema.epid - \bold{TRUE}, \bold{FALSE}, "sn", "epid", "date", "case_nm", "wind_nm", "length", "length_arrow", "case_overlap_methods" or "recurrence_overlap_methods"
 #' \item schema.pane - \bold{TRUE}, \bold{FALSE}, "sn", "pane", "date", "case_nm" or "window_label"
 #' \item schema.pid - \bold{TRUE}, \bold{FALSE}, "sn" or "pid"
 #' }
@@ -214,7 +214,7 @@ schema.epid <- function(x, title = NULL, show_labels = c("length_arrow"),
 
   # Information to show in the plot
   if(isTRUE(show_labels)){
-    show_labels <- c("sn", "epid", "date", "case_nm", "length_label",
+    show_labels <- c("sn", "epid", "date", "case_nm", "wind_nm", "length",
                      "length_arrow", "case_overlap_methods","recurrence_overlap_methods")
   }
 
@@ -367,13 +367,14 @@ schema.epid <- function(x, title = NULL, show_labels = c("length_arrow"),
     case_l_ar$end[case_l_ar$bck_dir] <- right_point(rev_len)
 
     case_l_ar$lab_y[case_l_ar$no_ar] <- case_l_ar$y[case_l_ar$no_ar]
-    case_l_ar$nl_l <- paste0(case_l_ar$wind_nm_l, "\n",
+    case_l_ar$nl_t <- case_l_ar$wind_nm_l
+    case_l_ar$nl_l <- paste0("\n",
                              format(number_line(case_l_ar$nl_s, case_l_ar$nl_e)),
                              " ", ifelse(is_dt, gsub("s$", "-", names(diyar::episode_unit)[case_l_ar$episode_unit]), "unit-"),
                              "difference.")
   }else{
     case_l_ar$no_ar <- logical()
-    case_l_ar$nl_l <- character()
+    case_l_ar$nl_t <- case_l_ar$nl_l <- character()
   }
 
   plot_pts <- nrow(plt_df)
@@ -427,9 +428,12 @@ schema.epid <- function(x, title = NULL, show_labels = c("length_arrow"),
         ggplot2::geom_segment(ggplot2::aes(x = .data$start, y = .data$y, xend = .data$end, yend = .data$y), linetype = "dashed", color = txt_col, alpha= .9, data = case_l_ar[case_l_ar$wind_nm_l == "Recurrence length" & case_l_ar$epid_total > 1 & case_l_ar$nl_s != case_l_ar$nl_e,], arrow = ggplot2::arrow(length = ggplot2::unit(scale_size(c(.5,.2), 500, plot_pts),"cm"), ends = "last", type = "open")) +
         ggplot2::geom_segment(ggplot2::aes(x = .data$pt_end, y = .data$y, xend = .data$start, yend = .data$y), linetype = "dotted", color = txt_col, alpha= .9, data = case_l_ar[case_l_ar$epid_total > 1 & case_l_ar$start != 0 & case_l_ar$end != 0,])
     }
-    if("length_label" %in% show_labels){
+    if("wind_nm" %in% show_labels){
       f <- f + ggplot2::geom_text(ggplot2::aes(x = (as.numeric(.data$start) + as.numeric(.data$end))/2, y= .data$y, label = .data$nl_l), data = case_l_ar[case_l_ar$nl_nm == "len" & case_l_ar$epid_total > 1,], nudge_y = scale_size(c(.02, .06), 500, plot_pts), size = scale_size(c(2,4), 500, plot_pts), color = txt_col, alpha= .9, vjust = "bottom")
     }
+    if("length" %in% show_labels){
+      f <- f + ggplot2::geom_text(ggplot2::aes(x = (as.numeric(.data$start) + as.numeric(.data$end))/2, y= .data$y, label = .data$nl_t), data = case_l_ar[case_l_ar$nl_nm == "len" & case_l_ar$epid_total > 1,], nudge_y = scale_size(c(.02, .06), 500, plot_pts), size = scale_size(c(2,4), 500, plot_pts), color = txt_col, alpha= .9, vjust = "bottom")
+    }
     f <- f +
       ggplot2::geom_text(ggplot2::aes(x = (as.numeric(.data$start) + as.numeric(.data$end))/2, y = .data$y, colour = .data$epid, label = .data$event_nm), nudge_y = scale_size(c(.01, .02), 500, plot_pts), size = scale_size(c(2,4), 500, plot_pts), vjust = "bottom", alpha= .7) +
       ggplot2::geom_text(ggplot2::aes(x = (as.numeric(.data$start) + as.numeric(.data$end))/2, y = .data$y, colour = .data$epid, label = .data$event_type), nudge_y = -scale_size(c(0, .01), 500, plot_pts), size = scale_size(c(2,4), 500, plot_pts), vjust = "top", alpha= .7)
